@@ -40,6 +40,7 @@ from lightwood.helpers.device import *
 from lightwood.helpers.general import *
 from lightwood.helpers.log import *
 from lightwood.helpers.numeric import *
+from lightwood.helpers.imputers import *
 from lightwood.helpers.parallelism import *
 from lightwood.helpers.seed import *
 from lightwood.helpers.text import *
@@ -92,10 +93,12 @@ def lookup_encoder(
         dtype.image: "Img2VecEncoder",
         dtype.rich_text: "PretrainedLangEncoder",
         dtype.short_text: "CategoricalAutoEncoder",
-        dtype.array: "ArrayEncoder",
-        dtype.tsarray: "TimeSeriesEncoder",
         dtype.quantity: "NumericEncoder",
-        dtype.audio: "MFCCEncoder"
+        dtype.audio: "MFCCEncoder",
+        dtype.num_array: "NumArrayEncoder",
+        dtype.cat_array: "CatArrayEncoder",
+        dtype.num_tsarray: "TimeSeriesEncoder",
+        dtype.cat_tsarray: "TimeSeriesEncoder",
     }
 
     # If column is a target, only specific feature representations are allowed that enable supervised tasks
@@ -124,7 +127,7 @@ def lookup_encoder(
                     "target_weights"
                 ] = problem_defintion.target_weights
 
-        if col_dtype in (dtype.integer, dtype.float, dtype.array, dtype.tsarray):
+        if col_dtype in (dtype.integer, dtype.float, dtype.num_array, dtype.num_tsarray):
             encoder_dict["args"][
                 "positive_domain"
             ] = "$statistical_analysis.positive_domain"
@@ -147,7 +150,10 @@ def lookup_encoder(
             if tss.horizon > 1:
                 encoder_dict["args"]["grouped_by"] = f"{gby}"
                 encoder_dict["args"]["timesteps"] = f"{tss.horizon}"
-                encoder_dict["module"] = "TsArrayNumericEncoder"
+                if col_dtype in [dtype.num_tsarray]:
+                    encoder_dict["module"] = "TsArrayNumericEncoder"
+                elif col_dtype in [dtype.cat_tsarray]:
+                    encoder_dict["module"] = "TsCatArrayEncoder"
 
         if "__mdb_ts_previous" in col_name or col_name in tss.historical_columns:
             encoder_dict["module"] = "TimeSeriesEncoder"
@@ -234,7 +240,7 @@ def generate_json_ai(
             }
         ]
 
-        if not tss.is_timeseries or tss.horizon == 1:
+        if (not tss.is_timeseries or tss.horizon == 1) and dtype_dict[target] not in (dtype.num_array, dtype.cat_array):
             submodels.extend(
                 [
                     {
@@ -252,7 +258,7 @@ def generate_json_ai(
                     },
                 ]
             )
-        elif tss.horizon > 1:
+        elif tss.is_timeseries and tss.horizon > 1:
             submodels.extend(
                 [
                     {
@@ -266,7 +272,7 @@ def generate_json_ai(
                 ]
             )
 
-            if tss.use_previous_target:
+            if tss.use_previous_target and dtype_dict[target] in (dtype.integer, dtype.float, dtype.quantity):
                 submodels.extend(
                     [
                         {
@@ -290,7 +296,10 @@ def generate_json_ai(
     }
 
     if tss.is_timeseries and tss.horizon > 1:
-        dtype_dict[target] = dtype.tsarray
+        if dtype_dict[target] in (dtype.integer, dtype.float, dtype.quantity):
+            dtype_dict[target] = dtype.num_tsarray
+        else:
+            dtype_dict[target] = dtype.cat_tsarray
 
     encoders = {
         target: lookup_encoder(
@@ -325,8 +334,10 @@ def generate_json_ai(
         accuracy_functions = ["r2_score"]
     elif output_dtype in [dtype.categorical, dtype.tags, dtype.binary]:
         accuracy_functions = ["balanced_accuracy_score"]
-    elif output_dtype in (dtype.array, dtype.tsarray):
-        accuracy_functions = ["evaluate_array_accuracy"]
+    elif output_dtype in (dtype.num_array, dtype.num_tsarray):
+        accuracy_functions = ["evaluate_num_array_accuracy"]
+    elif output_dtype in (dtype.cat_array, dtype.cat_tsarray):
+        accuracy_functions = ["evaluate_cat_array_accuracy"]
     else:
         raise Exception(
             f"Please specify a custom accuracy function for output type {output_dtype}"
@@ -335,7 +346,7 @@ def generate_json_ai(
     # special dispatch for t+1 time series forecasters
     if is_ts:
         if output_dtype in [dtype.integer, dtype.float]:
-            accuracy_functions = ["evaluate_array_accuracy"]
+            accuracy_functions = ["evaluate_num_array_accuracy"]
 
     if problem_definition.time_aim is None:
         # 5 days
@@ -548,6 +559,7 @@ def _add_implicit_values(json_ai: JsonAI) -> JsonAI:
                 "dtype_dict": "$dtype_dict",
                 "target": "$target",
                 "mode": "$mode",
+                "imputers": "$imputers",
                 "timeseries_settings": "$problem_definition.timeseries_settings",
                 "anomaly_detection": "$problem_definition.anomaly_detection",
             },
@@ -664,6 +676,14 @@ def code_from_json_ai(json_ai: JsonAI) -> str:
         if json_ai.dtype_dict[k] not in (dtype.invalid, dtype.empty):
             dtype_dict[k] = json_ai.dtype_dict[k]
 
+    # Populate imputers
+    imputer_dict = {}
+    if json_ai.imputers:
+        for imputer in json_ai.imputers:
+            imputer_dict[imputer['args']['target'].replace('\'', '').replace('\"', '')] = call(imputer)
+    json_ai.imputers = imputer_dict
+    imputers = inline_dict(json_ai.imputers)
+
     # Populate encoders
     encoder_dict = {}
     for col_name, encoder in json_ai.encoders.items():
@@ -752,6 +772,7 @@ self.analysis_blocks = [{', '.join([call(block) for block in json_ai.analysis_bl
 
     clean_body = f"""
 log.info('Cleaning the data')
+self.imputers = {imputers}
 data = {call(json_ai.cleaner)}
 
 # Time-series blocks
@@ -802,7 +823,7 @@ encoder_prepping_dict = {{}}
 
 # Prepare encoders that do not require learned strategies
 for col_name, encoder in self.encoders.items():
-    if not encoder.is_trainable_encoder:
+    if col_name != self.target and not encoder.is_trainable_encoder:
         encoder_prepping_dict[col_name] = [encoder, concatenated_train_dev[col_name], 'prepare']
         log.info(f'Encoder prepping dict length of: {{len(encoder_prepping_dict)}}')
 
@@ -820,7 +841,7 @@ if self.target not in parallel_prepped_encoders:
 
 # Prepare any non-target encoders that are learned
 for col_name, encoder in self.encoders.items():
-    if encoder.is_trainable_encoder:
+    if col_name != self.target and encoder.is_trainable_encoder:
         priming_data = pd.concat([data['train'], data['dev']])
         kwargs = {{}}
         if self.dependencies[col_name]:
@@ -834,7 +855,7 @@ for col_name, encoder in self.encoders.items():
 
         # If an encoder representation requires the target, provide priming data
         if hasattr(encoder, 'uses_target'):
-            kwargs['encoded_target_values'] = parallel_prepped_encoders[self.target].encode(priming_data[self.target])
+            kwargs['encoded_target_values'] = self.encoders[self.target].encode(priming_data[self.target])
 
         encoder.prepare(data['train'][col_name], data['dev'][col_name], **kwargs)
 
