@@ -10,6 +10,7 @@ import pandas as pd
 from lightwood.api.dtype import dtype
 from lightwood.helpers import text
 from lightwood.helpers.log import log
+from lightwood.helpers.imputers import BaseImputer
 from lightwood.api.types import TimeseriesSettings
 from lightwood.helpers.numeric import is_nan_numeric
 
@@ -23,10 +24,11 @@ def cleaner(
     mode: str,
     timeseries_settings: TimeseriesSettings,
     anomaly_detection: bool,
+    imputers: Dict[str, BaseImputer] = {},
     custom_cleaning_functions: Dict[str, str] = {}
 ) -> pd.DataFrame:
     """
-    The cleaner is a function which takes in the raw data, plus additional information about it's types and about the problem. Based on this it generates a "clean" representation of the data, where each column has an ideal standardized type and all malformed or otherwise missing or invalid elements are turned into ``None``
+    The cleaner is a function which takes in the raw data, plus additional information about it's types and about the problem. Based on this it generates a "clean" representation of the data, where each column has an ideal standardized type and all malformed or otherwise missing or invalid elements are turned into ``None``. Optionally, these ``None`` values can be replaced with imputers.
 
     :param data: The raw data
     :param dtype_dict: Type information for each column
@@ -34,6 +36,7 @@ def cleaner(
     :param identifiers: A dict containing all identifier typed columns
     :param target: The target columns
     :param mode: Can be "predict" or "train"
+    :param imputers: The key corresponds to the single input column that will be imputed by the object. Refer to the imputer documentation for more details.
     :param timeseries_settings: Timeseries related settings, only relevant for timeseries predictors, otherwise can be the default object
     :param anomaly_detection: Are we detecting anomalies with this predictor?
 
@@ -54,6 +57,10 @@ def cleaner(
     if timeseries_settings.is_timeseries:
         data = clean_timeseries(data, timeseries_settings)
 
+    for col, imputer in imputers.items():
+        cols = [col] + [col for col in imputer.dependencies]
+        data[col] = imputer.impute(data[cols])
+
     return data
 
 
@@ -94,14 +101,17 @@ def get_cleaning_func(data_dtype: dtype, custom_cleaning_functions: Dict[str, st
     elif data_dtype in (dtype.date, dtype.datetime):
         clean_func = _standardize_datetime
 
-    elif data_dtype in (dtype.float, dtype.tsarray):
+    elif data_dtype in (dtype.float, dtype.num_tsarray):
         clean_func = _clean_float
 
     elif data_dtype in (dtype.integer):
         clean_func = _clean_int
 
-    elif data_dtype in (dtype.array):
-        clean_func = _standardize_array
+    elif data_dtype in (dtype.num_array):
+        clean_func = _standardize_num_array
+
+    elif data_dtype in (dtype.cat_array):
+        clean_func = _standardize_cat_array
 
     elif data_dtype in (dtype.tags):
         clean_func = _tags_to_tuples
@@ -116,7 +126,8 @@ def get_cleaning_func(data_dtype: dtype, custom_cleaning_functions: Dict[str, st
         dtype.binary,
         dtype.audio,
         dtype.image,
-        dtype.video
+        dtype.video,
+        dtype.cat_tsarray
     ):
         clean_func = _clean_text
 
@@ -166,7 +177,7 @@ def _tags_to_tuples(tags_str: str) -> Tuple[str]:
         return tuple()
 
 
-def _standardize_array(element: object) -> Optional[Union[List[float], float]]:
+def _standardize_num_array(element: object) -> Optional[Union[List[float], float]]:
     """
     Given an array of numbers in the form ``[1, 2, 3, 4]``, converts into a numerical sequence.
 
@@ -175,7 +186,7 @@ def _standardize_array(element: object) -> Optional[Union[List[float], float]]:
 
     Ex of edge case:
     >> element = [1]
-    >> _standardize_array(element)
+    >> _standardize_num_array(element)
     >> 1
     """
     try:
@@ -194,6 +205,33 @@ def _standardize_array(element: object) -> Optional[Union[List[float], float]]:
     return element
 
 
+def _standardize_cat_array(element: List) -> Optional[List[str]]:
+    """
+    Given an array, replace non-string with string casted (or, failing that, None) tokens. None values are kept.
+
+    :param element: An array-like element in a sequence
+    :returns: standardized array OR label IF edge case
+
+    Ex of edge case:
+    >> element = ['a']
+    >> _standardize_cat_array(element)
+    >> 'a'
+    """
+    if len(element) == 1:
+        return element[0]
+    else:
+        new_element = []
+        for sub_elt in element:
+            try:
+                new_sub_elt = str(sub_elt) if sub_elt else None
+                new_element.append(new_sub_elt)
+            except TypeError:
+                new_element.append(None)
+        element = new_element
+
+    return element
+
+
 # ------------------------- #
 # Integers/Floats/Quantities
 # ------------------------- #
@@ -232,8 +270,13 @@ def _clean_quantity(element: object) -> Optional[float]:
 # ------------------------- #
 # Text
 # ------------------------- #
-def _clean_text(element: object) -> str:
-    return str(element)
+def _clean_text(element: object) -> Union[str, None]:
+    if isinstance(element, str):
+        return element
+    elif element is None or element != element:
+        return None
+    else:
+        return str(element)
 
 
 # ------------------------- #
@@ -291,6 +334,7 @@ def _remove_columns(data: pd.DataFrame, identifiers: Dict[str, object], target:
         exceptions += timeseries_settings.group_by
 
     to_drop = [x for x in to_drop if x in data.columns and x not in exceptions]
+    log.info(f'Dropping features: {to_drop}')
     data = data.drop(columns=to_drop)
 
     if mode == "train":
