@@ -67,11 +67,15 @@ class EncodedDs(Dataset):
                 if hasattr(self.encoders[col], 'data_window'):
                     cols = [self.target] + [f'{self.target}_timestep_{i}'
                                             for i in range(1, self.encoders[col].data_window)]
+                    data = [self.data_frame[cols].iloc[idx].tolist()]
                 else:
                     cols = [col]
+                    data = self.data_frame[cols].iloc[idx].tolist()
 
-                data = self.data_frame[cols].iloc[idx].tolist()
                 encoded_tensor = self.encoders[col].encode(data, **kwargs)[0]
+                if torch.isnan(encoded_tensor).any() or torch.isinf(encoded_tensor).any():
+                    raise Exception(f'Encoded tensor: {encoded_tensor} contains nan or inf values, this tensor is \
+                                      the encoding of column {col} using {self.encoders[col].__class__}')
                 if col != self.target:
                     X = torch.cat([X, encoded_tensor])
                 else:
@@ -103,6 +107,8 @@ class EncodedDs(Dataset):
             deps = [dep for dep in self.encoders[column_name].dependencies if dep in self.data_frame.columns]
             kwargs['dependency_data'] = {dep: self.data_frame[dep].tolist() for dep in deps}
         encoded_data = self.encoders[column_name].encode(self.data_frame[column_name], **kwargs)
+        if torch.isnan(encoded_data).any() or torch.isinf(encoded_data).any():
+            raise Exception(f'Encoded tensor: {encoded_data} contains nan or inf values')
 
         if not isinstance(encoded_data, torch.Tensor):
             raise Exception(
