@@ -6,5 +6,9 @@ from lightwood.mixer.lightgbm_array import LightGBMArray
 from lightwood.mixer.sktime import SkTime
 from lightwood.mixer.regression import Regression
 
+try:
+    from lightwood.mixer.qclassic import QClassic
+except Exception:
+    QClassic = None
 
-__all__ = ['BaseMixer', 'Neural', 'LightGBM', 'LightGBMArray', 'Unit', 'Regression', 'SkTime']
+__all__ = ['BaseMixer', 'Neural', 'LightGBM', 'LightGBMArray', 'Unit', 'Regression', 'SkTime', 'QClassic']
