@@ -90,12 +90,14 @@ class Neural(BaseMixer):
     def _select_criterion(self) -> torch.nn.Module:
         if self.dtype_dict[self.target] in (dtype.categorical, dtype.binary):
             criterion = TransformCrossEntropyLoss(weight=self.target_encoder.index_weights.to(self.model.device))
-        elif self.dtype_dict[self.target] in (dtype.tags):
+        elif self.dtype_dict[self.target] in (dtype.tags, dtype.cat_tsarray):
             criterion = nn.BCEWithLogitsLoss()
-        elif (self.dtype_dict[self.target] in (dtype.integer, dtype.float, dtype.tsarray, dtype.quantity)
+        elif self.dtype_dict[self.target] in (dtype.cat_array, ):
+            criterion = nn.L1Loss()
+        elif (self.dtype_dict[self.target] in (dtype.integer, dtype.float, dtype.num_tsarray, dtype.quantity)
                 and self.timeseries_settings.is_timeseries):
             criterion = nn.L1Loss()
-        elif self.dtype_dict[self.target] in (dtype.integer, dtype.float, dtype.quantity):
+        elif self.dtype_dict[self.target] in (dtype.integer, dtype.float, dtype.quantity, dtype.num_array):
             criterion = MSELoss()
         else:
             criterion = MSELoss()
